from setuptools import setup

setup(
    name="VKLong",
    version="0.2.0.2",
    description="Simple wrapper to make VK-Bot on Longpoll API",
    install_requires=[
        'requests'
     ],
     author="LeetCrash",
     author_email="leetcrash.official@gmail.com",
     keywords=[
        "vk api",
        "vk api library",
        "vk longpoll",
        "vk bot",
        "vklong",
        "vkapi",
        "vk long poll bot"
     ],
     zip_safe=False
)